@@ -82,12 +82,12 @@ function display_result(&$tag) {
     $hiddendata['name_match'] = $_POST['name_match'];
 
     /* 桼̾ */
-    $user = htmlspecialchars($dispusr);
+    $user = escape_html($dispusr);
 
     /* ɥᥤ̾ */
     $domain = "";
     if (isset($add_data["domain"]) === TRUE) {
-        $domain = htmlspecialchars($add_data["domain"]);
+        $domain = escape_html($add_data["domain"]);
     }
 
     /* ѥ */
@@ -104,7 +104,7 @@ function display_result(&$tag) {
     /* ̥ѥ */
     $indivipass = "";
     if (isset($add_data["indivipass"]) === TRUE) {
-        $indivipass = htmlspecialchars($add_data["indivipass"]);
+        $indivipass = escape_html($add_data["indivipass"]);
     }
 
     /* Ź沽롼 */
@@ -129,7 +129,7 @@ function display_result(&$tag) {
     /* hiddenǡ */
     $hidden_data = "";
     foreach($hiddendata as $hidkey => $hidval) {
-        $hidval = htmlspecialchars($hidval);
+        $hidval = escape_html($hidval);
         $hidden_data .= "<input type=\"hidden\" name=\"$hidkey\" value=\"$hidval\">";
     }
 
@@ -238,7 +238,7 @@ if (isset($_POST['form_name']) === TRUE) {
 }
 
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);
+$dispusr = escape_html($ldapdata[0][$dispusr][0]);
 
 /* ݻͼ */
 $del_list = "";
@@ -282,7 +282,7 @@ if (isset($_POST["add"]) === TRUE) {
 /* 󥻥 */
 } elseif (isset($_POST["cancel"]) === TRUE) {
     /* ̤ */
-    page_location_search("samma_list.php", $del_list);
+    page_location_search("samma_list.php");
     exit (0);
 
 }
